@@ -93,7 +93,7 @@ char *demux_debug = NULL;
 int ac3_audio_stream = -1;
 int dts_audio_stream = -1;
 int mpeg_audio_stream = -1;
-int pcm_audio_stream = -1;
+int lpcm_audio_stream = -1;
 int mpeg_video_stream = -1;
 int subpicture_stream = -1;
 int nav_stream = -1;
@@ -103,7 +103,7 @@ static int child_killed = 0;
 
 void usage(void)
 {
-  fprintf(stderr, "Usage: %s [-h] [-u cli|gui] [<path>]", program_name);
+  fprintf(stderr, "Usage: %s [-h] [-u cli|gui] [<path>]\n", program_name);
   //"[-a <ac3_stream#>] [-m <mpeg_audio_stream#>] [-p <pcm_audio_stream#>] [-v <mpeg_video_stream#>] [-s <subpicture_stream#>] [-n] [-f <fps>] [-r <#ouput_bufs>] [-o <file_offset>] [-d <videodebug_level>] [-D <demuxdebug_level>] <input file>\n", program_name);
 }
 
@@ -224,6 +224,9 @@ static int streamid_to_capability(uint8_t stream_id, uint8_t subtype)
     } else if((subtype >= 0x88) && (subtype < 0x90)) {
       cap = DECODE_DTS_AUDIO;
       
+    } else if((subtype >= 0xA0) && (subtype < 0xA8)) {
+      cap = DECODE_LPCM_AUDIO;
+      
     } else if((subtype >= 0x20) && (subtype < 0x40)) {
       cap = DECODE_DVD_SPU;
     }
@@ -252,6 +255,9 @@ static char *streamid_to_decoderstr(uint8_t stream_id, uint8_t subtype)
     } else if((subtype >= 0x88) && (subtype < 0x90)) {
       name = getenv("DVDP_DTS");
 
+    } else if((subtype >= 0xA0) && (subtype < 0xA8)) {
+      name = getenv("DVDP_LPCM");
+
     } else if((subtype >= 0x20) && (subtype < 0x40)) {
       name = getenv("DVDP_SPU");
     }
@@ -748,7 +754,7 @@ int main(int argc, char *argv[])
       mpeg_audio_stream = atoi(optarg);
       break;
     case 'p':
-      pcm_audio_stream = atoi(optarg);
+      lpcm_audio_stream = atoi(optarg);
       break;
     case 'v':
       mpeg_video_stream = atoi(optarg);
@@ -834,7 +840,7 @@ int main(int argc, char *argv[])
   
   /* If any streams are specified on the commadline, dexmux only those */
   /*
-  if((ac3_audio_stream & mpeg_audio_stream & pcm_audio_stream &
+  if((ac3_audio_stream & mpeg_audio_stream & lpcm_audio_stream &
       dts_audio_stream & mpeg_video_stream & subpicture_stream &
       nav_stream) == -1) {
     ev.demuxdefault.state = 1;
@@ -999,7 +1005,7 @@ int register_stream(uint8_t stream_id, uint8_t subtype)
   int state;
   
   /* If any stream is specified on the commadline, dexmux only those */
-  if((ac3_audio_stream & mpeg_audio_stream & pcm_audio_stream &
+  if((ac3_audio_stream & mpeg_audio_stream & lpcm_audio_stream &
       dts_audio_stream & mpeg_video_stream & subpicture_stream &
       nav_stream) == -1)
     state = 0;
@@ -1041,6 +1047,22 @@ int register_stream(uint8_t stream_id, uint8_t subtype)
       
     }
 
+    if(state) {
+
+      if((subtype == (0xA0 | (lpcm_audio_stream & 0x7))) &&
+	 (lpcm_audio_stream >= 0) && (lpcm_audio_stream < 8)) {
+	return 1;
+      }
+      
+    } else {
+      
+      /* dvd, it's an lpcm stream ok */
+      if((subtype >= 0xA0) && (subtype < 0xA8)) {
+	return 1;
+      }
+      
+    }
+
     if(state) {
 
       if((subtype == (0x20 | (subpicture_stream & 0x1f))) &&
@@ -1134,10 +1156,12 @@ void destroy_msgq(void)
 int get_buffer(int size, shm_bufinfo_t *bufinfo)
 {
   int shmid;
-  
+  /* This also creates the image buffers that will be sent to attached
+   * from the X server if we use Xv.  So we need to make sure that it
+   * has permissions to attach / read it.  */
   if((shmid = shmget(IPC_PRIVATE,
 		     size,
-		     IPC_CREAT | 0600)) == -1) {
+		     IPC_CREAT | 0644)) == -1) {
     perror("*ctrl: get_buffer, shmget failed");
     return -1;
   }
