@@ -30,7 +30,6 @@
 #include <unistd.h>
 #include <errno.h>
 
-extern char *program_name;
 static char *new_file(void);
 
 JSAMPLE * jpg_buffer;	/* Points to large array of R,G,B-order data */
@@ -194,7 +193,7 @@ void screenshot_yuv_jpg(yuv_image_t *yuv_data, XImage *ximg,
 
 static char *new_file(void) {
     char *pre = "shot";
-    int i = 0;
+    static int i = 0;
     int fd;
     static char full_name[20];
 
