@@ -74,7 +74,7 @@ typedef struct {
   int has_highlight;
   uint8_t color[4];
   uint8_t contrast[4];
-} spu_t;
+} spu_handle_t;
 
 typedef struct {
   uint8_t color[4];
@@ -86,8 +86,6 @@ typedef struct {
 } highlight_t;
 
 
-extern char *program_name;
-
 extern ctrl_data_t *ctrl_data;
 extern ctrl_time_t *ctrl_time;
 
@@ -101,7 +99,7 @@ static int aligned;
 static uint16_t fieldoffset[2];
 static uint16_t field = 0;
 
-static spu_t spu_info = { 0 };
+static spu_handle_t spu_info = { 0 };
 
 static int initialized = 0;
 
@@ -312,8 +310,8 @@ static int get_q(char *dst, int readlen, uint64_t *display_base_time,
   
   data_elem = &data_elems[q_elems[elem].data_elem_index];
 
-  off = data_elem->off;
-  len = data_elem->len;
+  off = data_elem->packet_data_offset+1;
+  len = data_elem->packet_data_len-1;
     
   PTS_DTS_flags = data_elem->PTS_DTS_flags;
   if(PTS_DTS_flags & 0x2) {
@@ -520,7 +518,7 @@ static inline uint8_t get_nibble (void)
 
 
 
-static void decode_dcsqt(spu_t *spu_info)
+static void decode_dcsqt(spu_handle_t *spu_info)
 {
   // init start position
   set_byte(spu_info->buffer);
@@ -545,7 +543,7 @@ static void decode_dcsqt(spu_t *spu_info)
 }
 
 
-static void decode_dcsq(spu_t *spu_info)
+static void decode_dcsq(spu_handle_t *spu_info)
 { 
   uint8_t command;
   uint32_t dummy;
@@ -892,7 +890,7 @@ static void display_mix_function_yuv(uint32_t color, uint32_t contrast,
 }
 
 
-static void decode_display_data(spu_t *spu_info, char *data, 
+static void decode_display_data(spu_handle_t *spu_info, char *data, 
 				int pixel_stride, int line_stride,
 				int blendyuv, int image_stride) 
 {
@@ -1050,7 +1048,7 @@ static void decode_display_data(spu_t *spu_info, char *data,
  *
  *
  */
-static int next_spu_cmd_pending(spu_t *spu_info)
+static int next_spu_cmd_pending(spu_handle_t *spu_info)
 {
   int start_time, offset;
   clocktime_t realtime, errtime, next_time;
@@ -1089,25 +1087,7 @@ static int next_spu_cmd_pending(spu_t *spu_info)
     spu_info->next_time = spu_info->base_time + start_time * 1024;
     //   timeadd(&spu_info->next_time, &spu_info->base_time, &spu_info->next_time);
   }
-  
-  if(ctrl_time[spu_info->scr_nr].offset_valid == OFFSET_NOT_VALID) {
-    return 0;
-  }
-  PTS_TO_CLOCKTIME(next_time, spu_info->next_time);
-  clocktime_get(&realtime);
-  calc_realtime_left_to_scrtime(&errtime, &realtime, &next_time,
-				&ctrl_time[spu_info->scr_nr].sync_point);
-  //  timesub(&errtime, &spu_info->next_time, &realtime);
 
-  if(TIME_SS(errtime) < 0 || TIME_S(errtime) < 0) {
-    //DNOTE("spu: time: %d.%09d\n",TIME_S(errtime),TIME_SS(errtime));
-    return 1;
-  }
-  if(spu_info->scr_nr < video_scr_nr) { // FIXME: assumes order of src_nr
-    //DNOTE("spu: spu_info->scr_nr != video_scr_nr\n");
-    return 1;
-  }
-  
   if(flush_to_scrid != -1) {
     if(ctrl_time[spu_info->scr_nr].scr_id < flush_to_scrid) {
 
@@ -1122,6 +1102,26 @@ static int next_spu_cmd_pending(spu_t *spu_info)
       flush_to_scrid = -1;
     }
   }
+
+  if(spu_info->scr_nr < video_scr_nr) { // FIXME: assumes order of src_nr
+    //DNOTE("spu: spu_info->scr_nr != video_scr_nr\n");
+    return 1;
+  }
+
+  if(ctrl_time[spu_info->scr_nr].offset_valid == OFFSET_NOT_VALID) {
+    //DNOTE("scr_nr: %d, OFFSET_NOT_VALID\n", spu_info->scr_nr);
+    return 0;
+  }
+  PTS_TO_CLOCKTIME(next_time, spu_info->next_time);
+  clocktime_get(&realtime);
+  calc_realtime_left_to_scrtime(&errtime, &realtime, &next_time,
+				&ctrl_time[spu_info->scr_nr].sync_point);
+  //  timesub(&errtime, &spu_info->next_time, &realtime);
+
+  if(TIME_SS(errtime) < 0 || TIME_S(errtime) < 0) {
+    //DNOTE("spu: errtime: %d.%09d\n",TIME_S(errtime),TIME_SS(errtime));
+    return 1;
+  }
   
   return 0;
 }
@@ -1234,7 +1234,7 @@ void flush_subpicture(int scr_id)
     return;
   }
   
-  //DNOTE("spu: flush_subpicture\n");
+  //DNOTE("spu: flush_subpicture to scr_id: %d\n", scr_id);
   flush_to_scrid = scr_id;
 
   while(next_spu_cmd_pending(&spu_info)) {
