@@ -25,6 +25,11 @@
 #include <time.h>
 #include <errno.h>
 
+#ifdef __bsdi__
+#include <sys/param.h>
+#include <sys/sysctl.h>
+#endif
+
 #ifndef HAVE_CLOCK_GETTIME
 #include <sys/time.h>
 #endif
@@ -39,8 +44,8 @@
 #include "timemath.h"
 #include "sync.h"
 #include "spu_mixer.h"
-
 #include "video_output.h"
+#include "xscreensaver-comm.h"
 
 #ifndef SHM_SHARE_MMU
 #define SHM_SHARE_MMU 0
@@ -64,8 +69,13 @@ int video_scr_nr;
 
 int process_interrupted = 0;
 
+Bool talk_to_xscreensaver;
+
 static int end_of_wait;
 
+static long clk_tck;
+static long min_time_left;
+
 AspectModeSrc_t aspect_mode = AspectModeSrcVM;
 AspectModeSrc_t aspect_sender;
 
@@ -495,16 +505,30 @@ static clocktime_t wait_until(clocktime_t *scr, sync_point_t *sp)
   clocktime_t real_time;
   struct sigaction act;
   struct sigaction oact;
-  
+
+  static clocktime_t last_ss_disable = {0,0};
+
   timer.it_interval.tv_sec = 0;
   timer.it_interval.tv_usec = 0;
   
   while(1) {
     
     end_of_wait = 0;
-   
+    
     clocktime_get(&real_time);
 
+    if(talk_to_xscreensaver) {
+       if(TIME_S(real_time) - TIME_S(last_ss_disable) > 50) {
+           clocktime_t prof_time;
+           nudge_xscreensaver();
+           clocktime_get(&prof_time);
+           timesub(&prof_time, &prof_time, &real_time);
+           fprintf(stderr, "ss disable took %ld.%09ld s\n",
+                  TIME_S(prof_time), TIME_SS(prof_time));
+           TIME_S(last_ss_disable) = TIME_S(real_time);
+       }
+    }
+
     calc_realtime_left_to_scrtime(&time_left, &real_time,
 				  scr, sp);
     /*
@@ -525,8 +549,8 @@ static clocktime_t wait_until(clocktime_t *scr, sync_point_t *sp)
       sigaction(SIGALRM, &act, &oact);
       setitimer(ITIMER_REAL, &timer, NULL);
 
-    } else if(TIME_SS(time_left) > (15*(CT_FRACTION/1000))) {
-      // less than 100ms but more than 15 ms left, lets wait
+    } else if(TIME_SS(time_left) > min_time_left) {
+      // less than 100ms but more than clktck/2 left, lets wait
       struct timespec sleeptime;
  
 #if 0
@@ -547,8 +571,8 @@ static clocktime_t wait_until(clocktime_t *scr, sync_point_t *sp)
 				    scr, sp);
       return time_left;
     } else {
-      // less than 15 ms left or negative time left, we cant sleep
-      // a shorter period than 10 ms so we return
+      // less than clktck/2 left or negative time left, we cant sleep
+      // a shorter period than clktck so we return
 
       return time_left;
     }
@@ -783,6 +807,8 @@ static void display_process()
   sig.sa_flags = 0;
   sigaction(SIGALRM, &sig, NULL);
 
+  talk_to_xscreensaver = look_for_good_xscreensaver();
+
   while(1) {
     //DNOTE("old_q_id: %d\n", old_q_id);
     old_data_q = cur_data_q;
@@ -937,8 +963,8 @@ static void display_process()
 	    wait_time.tv_sec, wait_time.tv_nsec);
     */
 
-    if(TIME_SS(wait_time) < -300*(CT_FRACTION/1000)) {
-      // more than 300 ms late
+    if(TIME_SS(wait_time) < -60*(CT_FRACTION/1000)) {
+      // more than 60 ms late, drop decoded pictures
       drop = 1;
     }
     
@@ -999,10 +1025,23 @@ void display_process_exit(void) {
 }
 
 
+#ifdef __bsdi__
 
-
-
-
+static int bsdi_getticks(void)
+{
+  int mib[2];
+  size_t olen = sizeof (struct clockinfo);
+  struct clockinfo ci;
+  
+  mib[0] = CTL_KERN;
+  mib[1] = KERN_CLOCKRATE;
+  if (sysctl(mib, 2, &ci, &olen, NULL, 0) < 0) {
+    perror("sysctl kern.clockrate");
+    return(100);
+  }
+  return ci.hz;
+}
+#endif
 
 
 static void usage()
@@ -1038,7 +1077,28 @@ int main(int argc, char **argv)
     }
   }
   
+  errno = 0;
+
+#ifdef __bsdi__
+  clk_tck = bsdi_getticks();
+#else
+  clk_tck = sysconf(_SC_CLK_TCK);
+#endif
   
+  if(clk_tck <= 0) {
+    // linux returns 0 as error also
+    if(errno != 0 && clk_tck == -1) {
+      perror("sysconf(_SC_CLK_TCK)");
+    } else {
+      fprintf(stderr, "sysconf(_SC_CLK_TCK), not supported\n");
+    }
+    //guessed default value
+    clk_tck = 100;
+  }
+
+  min_time_left = (CT_FRACTION/clk_tck)/2;
+
+  DNOTE("CLK_TCK: %ld\n", clk_tck);
 
   if(msgqid != -1) {
     
