@@ -79,7 +79,6 @@ static int xv_id;
 #endif /* HAVE_XV */
 
 
-extern char *program_name;
 //ugly hack
 extern data_q_t *cur_data_q;
 /*
@@ -135,6 +134,7 @@ static Display *mydisplay = NULL;
 static int screen_nr;
 static GC mygc;
 static char title[100];
+
 static int color_depth, pixel_stride, mode;
 
 
@@ -197,10 +197,12 @@ static Bool true_predicate(Display *dpy, XEvent *ev, XPointer arg)
 
 static Cursor hidden_cursor;
 
-
+#ifndef MIN
 #define MIN(a,b) ((a) < (b) ? (a) : (b))
+#endif
+#ifndef MAX
 #define MAX(a,b) ((a) > (b) ? (a) : (b))
-
+#endif
 
 
 
@@ -513,7 +515,7 @@ void init_config(Display *dpy)
 
 
   
-  if(get_video_config(&cfg_video) == 0) {
+  if(get_video_config(&cfg_video) == -1) {
     ERROR("init_config(): Couldn't read any config files\n");
   }
   
@@ -579,6 +581,8 @@ void init_config(Display *dpy)
       orig = DpyInfoOriginUser;
     } else if(!strcmp(cfg_display->resolution_src, "XF86VidMode")) {
       orig = DpyInfoOriginXF86VidMode;
+    } else if(!strcmp(cfg_display->resolution_src, "Xinerama")) {
+      orig = DpyInfoOriginXinerama;
     }
   }
   
@@ -592,6 +596,9 @@ void init_config(Display *dpy)
     case DpyInfoOriginXF86VidMode:
       orig_str = "XF86VidMode";
       break;
+    case DpyInfoOriginXinerama:
+      orig_str = "Xinerama";
+      break;
     case DpyInfoOriginUser:
       orig_str = "user";
       break;
@@ -602,7 +609,7 @@ void init_config(Display *dpy)
   }
   
   DpyInfoUpdateGeometry(dpy, screen_nr);
-  DpyInfoUpdateResolution(dpy, screen_nr);
+  DpyInfoUpdateResolution(dpy, screen_nr, 0, 0);
   
   /* Query and calculate the displays aspect rate. */
   {
@@ -620,6 +627,13 @@ void init_config(Display *dpy)
 	 dpy_sar_frac_n, dpy_sar_frac_d,
 	 (double)dpy_sar_frac_n/(double)dpy_sar_frac_d);
   }
+
+  if(cfg_display->initial_state.fullscreen == 1) {
+    zoom_mode = ZoomModeFullScreen;
+  } else {
+    zoom_mode = ZoomModeResizeAllowed;
+  }
+
 }
 
 void display_reset(void)
@@ -657,14 +671,16 @@ void display_init(int padded_width, int padded_height,
 {
   static int initialized = 0;
   Screen *scr;
-  XSizeHints hint;
+  XSizeHints *size_hints;
+  XClassHint *class_hints;
+  char *string;
   XEvent xev;
   XGCValues xgcv;
   Colormap theCmap;
   XWindowAttributes attribs;
   XSetWindowAttributes xswa;
   unsigned long xswamask;
-
+  XTextProperty window_name_prop, icon_name_prop;
   scale.image_width = padded_width;
   scale.image_height = padded_height;
   
@@ -702,11 +718,13 @@ void display_init(int padded_width, int padded_height,
     XMatchVisualInfo(mydisplay, screen_nr, color_depth, TrueColor, &vinfo);
     //DNOTE("X11 visual id is %lx\n", vinfo.visualid);
     
-    hint.x = 0;
-    hint.y = 0;
-    hint.width = scale.image_width;
-    hint.height = scale.image_height;
-    hint.flags = PPosition | PSize;
+    size_hints = XAllocSizeHints();
+    
+    size_hints->x = 0;
+    size_hints->y = 0;
+    size_hints->width = scale.image_width;
+    size_hints->height = scale.image_height;
+    size_hints->flags = /*PPosition |*/ PSize;
     
     theCmap   = XCreateColormap(mydisplay, RootWindow(mydisplay,screen_nr), 
 				vinfo.visual, AllocNone);
@@ -719,7 +737,8 @@ void display_init(int padded_width, int padded_height,
     window.win_state = WINDOW_STATE_NORMAL;
     
     window.win = XCreateWindow(mydisplay, RootWindow(mydisplay,screen_nr),
-			       hint.x, hint.y, hint.width, hint.height, 
+			       size_hints->x, size_hints->y,
+			       size_hints->width, size_hints->height, 
 			       4, color_depth, CopyFromParent, vinfo.visual, 
 			       xswamask, &xswa);
     
@@ -731,10 +750,27 @@ void display_init(int padded_width, int padded_height,
     create_transparent_cursor(mydisplay, window.win);
     
     /* Tell other applications/the window manager about us. */
-    snprintf(&title[0], 99, "Ogle v%s", VERSION);
-    XSetStandardProperties(mydisplay, window.win, &title[0], &title[0], 
-			   None, NULL, 0, &hint);
     
+    class_hints = XAllocClassHint();
+    class_hints->res_class = "Ogle";
+    
+    string = &title[0];
+
+    snprintf(&title[0], 99, "Ogle");
+    XStringListToTextProperty(&string, 1, &icon_name_prop);
+
+    snprintf(&title[0], 99, "Ogle v%s", VERSION);
+    XStringListToTextProperty(&string, 1, &window_name_prop);
+    
+    XSetWMProperties(mydisplay, window.win,
+		     &window_name_prop,
+		     &icon_name_prop,
+		     NULL, 0,
+		     size_hints, NULL, class_hints);
+
+    XFree(class_hints);
+    XFree(size_hints);
+
     /* Map window. */
     XMapWindow(mydisplay, window.win);
     
@@ -796,7 +832,7 @@ void display_init(int padded_width, int padded_height,
 		  padded_width, padded_height);
 
   /* Try XShm if we didn't have/couldn't use Xv. 
-     This allso falls back to normal X11 if XShm fails. */
+     This also falls back to normal X11 if XShm fails. */
   if(!use_xv) {
     display_init_xshm();
   }
@@ -808,6 +844,7 @@ void display_init(int padded_width, int padded_height,
       fb_fd = open("/dev/fb", O_RDWR);
       yuyv_fb = (unsigned int *)mmap(NULL, 4*1024*1024, PROT_READ | PROT_WRITE,
 				     MAP_SHARED, fb_fd, 0x0701a000);
+
       if(yuyv_fb == MAP_FAILED) {
 	perror("mmap");
 	exit(1);
@@ -825,7 +862,9 @@ void display_init(int padded_width, int padded_height,
     /* Let the user know what mode we are running in. */
     snprintf(&title[0], 99, "Ogle v%s %s%s", VERSION, 
 	     use_xv ? "Xv " : "", use_xshm ? "XShm " : "");
-    XStoreName(mydisplay, window.win, &title[0]);
+
+    XStringListToTextProperty(&string, 1, &window_name_prop);
+    XSetWMName(mydisplay, window.win, &window_name_prop);
   }
   initialized = 1;
 }
@@ -857,6 +896,7 @@ static void display_change_size(yuv_image_t *img, int new_width,
       XResizeWindow(mydisplay, window.win, 
 		    scale.image_width, scale.image_height);
     }
+
     return;
   }
   
@@ -906,7 +946,7 @@ static void display_change_size(yuv_image_t *img, int new_width,
     }
     
     /* Get a shared memory segment */
-    shm_info.shmid = shmget(IPC_PRIVATE, alloc_size, IPC_CREAT | 0777);
+    shm_info.shmid = shmget(IPC_PRIVATE, alloc_size, IPC_CREAT | 0666);
 
     if(shm_info.shmid == -1) {
       FATAL("display_change_size");
@@ -1063,8 +1103,18 @@ static void display_adjust_size(yuv_image_t *current_image,
 
 
 static void display_toggle_fullscreen(yuv_image_t *current_image) {
-
-  DpyInfoUpdateResolution(mydisplay, screen_nr);
+  int root_x, root_y;
+  Window dummy_win;
+  
+  XTranslateCoordinates(mydisplay, window.win,
+			DefaultRootWindow(mydisplay), 
+			0,
+			0,
+			&root_x,
+			&root_y,
+			&dummy_win);
+  
+  DpyInfoUpdateResolution(mydisplay, screen_nr, root_x, root_y);
   
   if(window.win_state != WINDOW_STATE_FULLSCREEN) {
     ChangeWindowState(mydisplay, window.win, WINDOW_STATE_FULLSCREEN);
@@ -1078,6 +1128,46 @@ static void display_toggle_fullscreen(yuv_image_t *current_image) {
 }
 
 
+void clear_borders(void)
+{
+  // top border
+  if(window.video_area.y > 0) {
+    XClearArea(mydisplay, window.win,
+	       0, 0,
+	       window.window_area.width,
+	       window.video_area.y - 0,
+	       False);
+  }
+  // bottom border
+  if((window.video_area.y + window.video_area.height) <
+     window.window_area.height) {
+    XClearArea(mydisplay, window.win,
+	       0, (window.video_area.y + window.video_area.height),
+	       window.window_area.width,
+	       window.window_area.height -
+	       (window.video_area.y + window.video_area.height),
+	       False);
+  }
+  // left border
+  if(window.video_area.x > 0) {
+    XClearArea(mydisplay, window.win,
+	       0, 0,
+	       window.video_area.x - 0,
+	       window.window_area.height,
+	       False);
+  }
+  // right border
+  if((window.video_area.x + window.video_area.width) <
+     window.window_area.width) {
+    XClearArea(mydisplay, window.win,
+	       (window.video_area.x + window.video_area.width), 0,
+	       window.window_area.width -
+	       (window.video_area.x + window.video_area.width),
+	       window.window_area.height,
+	       False);
+  }
+}
+
 void check_x_events(yuv_image_t *current_image)
 {
   XEvent ev;
@@ -1270,42 +1360,10 @@ void check_x_events(yuv_image_t *current_image)
 			      &window.window_area.y,
 			      &dummy_win);
 	
-	// top border
-	if(window.video_area.y > 0) {
-	  XClearArea(mydisplay, window.win,
-		     0, 0,
-		     window.window_area.width,
-		     window.video_area.y - 0,
-		     False);
-	}
-	// bottom border
-	if((window.video_area.y + window.video_area.height) <
-	   window.window_area.height) {
-	  XClearArea(mydisplay, window.win,
-		     0, (window.video_area.y + window.video_area.height),
-		     window.window_area.width,
-		     window.window_area.height -
-		     (window.video_area.y + window.video_area.height),
-		     False);
-	}
-	// left border
-	if(window.video_area.x > 0) {
-	  XClearArea(mydisplay, window.win,
-		     0, 0,
-		     window.video_area.x - 0,
-		     window.window_area.height,
-		     False);
-	}
-	// right border
-	if((window.video_area.x + window.video_area.width) <
-	   window.window_area.width) {
-	  XClearArea(mydisplay, window.win,
-		     (window.video_area.x + window.video_area.width), 0,
-		     window.window_area.width -
-		     (window.video_area.x + window.video_area.width),
-		     window.window_area.height,
-		     False);
-	}
+	DpyInfoUpdateResolution(mydisplay, screen_nr,
+				window.window_area.x,
+				window.window_area.y);
+	clear_borders();
       }
       break;    
     default:
@@ -1336,6 +1394,13 @@ void display(yuv_image_t *current_image)
       sar_frac_d = current_image->info->picture.sar_frac_d;
       
       display_adjust_size(current_image, -1, -1);
+      //TODO move this
+      XClearArea(mydisplay, window.win,
+		 0, 0,
+		 window.window_area.width,
+		 window.window_area.height,
+		 False);
+
     }
   }
   if(aspect_mode == AspectModeSrcVM) {
@@ -1346,6 +1411,13 @@ void display(yuv_image_t *current_image)
       sar_frac_d = aspect_new_frac_d;
     
       display_adjust_size(current_image, -1, -1);
+      //TODO move this
+      XClearArea(mydisplay, window.win,
+		 0, 0,
+		 window.window_area.width,
+		 window.window_area.height,
+		 False);
+
     }
   }
   
@@ -1751,19 +1823,29 @@ static void draw_win_xv(window_info *dwin)
 			      window.video_area.width) / 2;
   window.video_area.y = (int)(window.window_area.height -
 			      window.video_area.height) / 2;
-  
-  XvShmPutImage(mydisplay, xv_port, dwin->win, mygc, xv_image, 
-		0, 0, 
-		dwin->image->info->picture.horizontal_size,
-		dwin->image->info->picture.vertical_size,
-		window.video_area.x,
-		window.video_area.y,
-		window.video_area.width,
-		window.video_area.height,
-		True);
-  
+  if(use_xshm) {
+    XvShmPutImage(mydisplay, xv_port, dwin->win, mygc, xv_image, 
+		  0, 0, 
+		  dwin->image->info->picture.horizontal_size,
+		  dwin->image->info->picture.vertical_size,
+		  window.video_area.x,
+		  window.video_area.y,
+		  window.video_area.width,
+		  window.video_area.height,
+		  True);
+  } else {
+    XvPutImage(mydisplay, xv_port, dwin->win, mygc, xv_image, 
+	       0, 0, 
+	       dwin->image->info->picture.horizontal_size,
+	       dwin->image->info->picture.vertical_size,
+	       window.video_area.x,
+	       window.video_area.y,
+	       window.video_area.width,
+	       window.video_area.height);
+    XFlush(mydisplay);
+  }
   //XFlush(mydisplay); ??
-  {
+  if(use_xshm) {
     XEvent ev;
     XEvent *e;
     e = &ev;
