@@ -63,16 +63,6 @@
 
 
 
-typedef struct _data_q_t {
-  int in_use;
-  int eoq;
-  q_head_t *q_head;
-  q_elem_t *q_elems;
-  data_buf_head_t *data_head;
-  picture_data_elem_t *data_elems;
-  yuv_image_t *image_bufs;
-  struct _data_q_t *next;
-} data_q_t;
 
 extern void handle_events(MsgEventQ_t *q, MsgEvent_t *ev);
 //extern int chk_for_msg();
@@ -166,6 +156,7 @@ yuv_image_t *dst_image;
 int last_gop_had_repeat_field_progressive_frame = 0;
 
 
+char *program_name;
 
 
 
@@ -284,6 +275,8 @@ int main(int argc, char **argv)
   int c;
   int output_client = 0;
   
+  program_name = argv[0];
+
   /* Parse command line options */
   while ((c = getopt(argc, argv, "d:r:f:m:hs")) != EOF) {
     switch (c) {
@@ -308,7 +301,7 @@ int main(int argc, char **argv)
 	      "  -d <level>   set debug level (default 0)\n"
 	      "  -r <buffers> set nr of buffers (default 3)\n"
 	      "  -s           disable shared memory\n", 
-	      argv[0]);
+	      program_name);
       return 1;
     }
   }
@@ -2440,7 +2433,7 @@ void sequence_display_extension(void)
       DPRINTF(2, "(forbidden)\n");
       break;
     case 0x1:
-      DPRINTF(2, "ITU-R 709\n");
+      DPRINTF(2, "ITU-R BT.709\n");
       break;
     case 0x2:
       DPRINTF(2, "Unspecified Video\n");
@@ -2449,10 +2442,10 @@ void sequence_display_extension(void)
       DPRINTF(2, "reserved\n");
       break;
     case 0x4:
-      DPRINTF(2, "ITU-R 624-4 System M\n");
+      DPRINTF(2, "ITU-R BT.470-2 System M\n");
       break;
     case 0x5:
-      DPRINTF(2, "ITU-R 624-4 System B,G\n");
+      DPRINTF(2, "ITU-R BT.470-2 System B,G\n");
       break;
     case 0x6:
       DPRINTF(2, "SMPTE 170M\n");
@@ -2474,7 +2467,7 @@ void sequence_display_extension(void)
       DPRINTF(2, "(forbidden)\n");
       break;
     case 0x1:
-      DPRINTF(2, "ITU-R 709\n");
+      DPRINTF(2, "ITU-R BT.709\n");
       break;
     case 0x2:
       DPRINTF(2, "Unspecified Video\n");
@@ -2483,10 +2476,10 @@ void sequence_display_extension(void)
       DPRINTF(2, "reserved\n");
       break;
     case 0x4:
-      DPRINTF(2, "ITU-R 624-4 System M\n");
+      DPRINTF(2, "ITU-R BT.470-2 System M\n");
       break;
     case 0x5:
-      DPRINTF(2, "ITU-R 624-4 System B,G\n");
+      DPRINTF(2, "ITU-R BT.470-2 System B,G\n");
       break;
     case 0x6:
       DPRINTF(2, "SMPTE 170M\n");
@@ -2511,7 +2504,7 @@ void sequence_display_extension(void)
       DPRINTF(2, "(forbidden)\n");
       break;
     case 0x1:
-      DPRINTF(2, "ITU-R 709\n");
+      DPRINTF(2, "ITU-R BT.709\n");
       break;
     case 0x2:
       DPRINTF(2, "Unspecified Video\n");
@@ -2523,7 +2516,7 @@ void sequence_display_extension(void)
       DPRINTF(2, "FCC\n");
       break;
     case 0x5:
-      DPRINTF(2, "ITU-R 624-4 System B,G\n");
+      DPRINTF(2, "ITU-R BT.470-2 System B,G\n");
       break;
     case 0x6:
       DPRINTF(2, "SMPTE 170M\n");
