@@ -291,7 +291,12 @@ typedef struct {
   int more_to_come;
 } DVDVideoAttributes_t;
 
-
+typedef struct {
+  DVDTitle_t title;     /**< TT number not VTS_TT number */
+  DVDPTT_t ptt;
+  DVDTimecode_t title_current;
+  DVDTimecode_t title_total;
+} DVDLocation_t;
 
 /* hack */
 
