@@ -28,6 +28,15 @@
 #include <sys/param.h>
 #endif
 
+
+
+
+
+
+
+
+
+
 /** @file
  * DVD navigator interface.
  * This file contains the functions that form the interface to
@@ -226,7 +235,7 @@ void DVDPerror(const char *str, DVDResult_t ErrCode)
  * Get the contents of all General Parameters
  * @todo implement function
  */
-DVDResult_t DVDGetAllGPRMs(DVDNav_t *nav, const DVDGPRMArray_t *Registers)
+DVDResult_t DVDGetAllGPRMs(DVDNav_t *nav, DVDGPRMArray_t *const Registers)
 {
   return DVD_E_NotImplemented;
 }
@@ -235,18 +244,45 @@ DVDResult_t DVDGetAllGPRMs(DVDNav_t *nav, const DVDGPRMArray_t *Registers)
  * Get the contents of all System Parameters
  * @todo implement function
  */
-DVDResult_t DVDGetAllSPRMs(DVDNav_t *nav, const DVDSPRMArray_t *Registers)
+DVDResult_t DVDGetAllSPRMs(DVDNav_t *nav, DVDSPRMArray_t *const Registers)
 {
   return DVD_E_NotImplemented;
 }
 
 /**
  * Get the current allowed user operations
- * @todo implement function
+ * @todo handle more return events.
+ * @todo more return values.
+ *
+ * @param nav Specifies the connection to the DVD navigator.
+ * @param uop Points to where the user operations will be written
+ *
+ * @return If successful DVD_E_Ok is returned. Otherwise an error code
+ * is returned.
+ *
+ * @retval DVD_E_Ok Success.
+ * @retval DVD_E_NotImplemented The function is not implemented.
  */
-DVDResult_t DVDGetCurrentUOPS(DVDNav_t *nav, const DVDUOP_t *uop)
+DVDResult_t DVDGetCurrentUOPS(DVDNav_t *nav, DVDUOP_t *const uop)
 {
-  return DVD_E_NotImplemented;
+  MsgEvent_t ev;
+  ev.type = MsgEventQDVDCtrl;
+  ev.dvdctrl.cmd.currentuops.type = DVDCtrlGetCurrentUOPS;
+
+  if(MsgSendEvent(nav->msgq, nav->client, &ev, 0) == -1) {
+    return DVD_E_Unspecified;
+  }
+
+  while(1) {
+    if(MsgNextEvent(nav->msgq, &ev) == -1) {
+      return DVD_E_Unspecified;
+    }
+    if((ev.type == MsgEventQDVDCtrl) &&
+       (ev.dvdctrl.cmd.type == DVDCtrlCurrentUOPS)) {
+      *uop = ev.dvdctrl.cmd.currentuops.uops;
+      return DVD_E_Ok;
+    }
+  }
 }
 
 /**
@@ -268,7 +304,7 @@ DVDResult_t DVDGetCurrentUOPS(DVDNav_t *nav, const DVDUOP_t *uop)
  * @retval DVD_E_NotImplemented The function is not implemented. 
  */
 DVDResult_t DVDGetAudioAttributes(DVDNav_t *nav, DVDAudioStream_t StreamNr,
-				  const DVDAudioAttributes_t *Attr)
+				  DVDAudioAttributes_t *const Attr)
 {
   MsgEvent_t ev;
   ev.type = MsgEventQDVDCtrl;
@@ -311,7 +347,7 @@ DVDResult_t DVDGetAudioAttributes(DVDNav_t *nav, DVDAudioStream_t StreamNr,
  * @retval DVD_E_NotImplemented The function is not implemented.
  */
 DVDResult_t DVDGetAudioLanguage(DVDNav_t *nav, DVDAudioStream_t StreamNr,
-				const DVDLangID_t *Language)
+				DVDLangID_t *const Language)
 {
   return DVD_E_NotImplemented;
 }
@@ -411,16 +447,15 @@ DVDResult_t DVDIsAudioStreamEnabled(DVDNav_t *nav, DVDAudioStream_t StreamNr,
  * @retval DVD_E_NotImplemented The function is not implemented.
  */
 DVDResult_t DVDGetDefaultAudioLanguage(DVDNav_t *nav,
-				       const DVDLangID_t *Language,
-				       const DVDAudioLangExt_t *AudioExtension)
+				       DVDLangID_t *const Language,
+				       DVDAudioLangExt_t *const AudioExtension)
 {
   return DVD_E_NotImplemented;
 }
 
 
 /** 
- * @todo Implement function.
- *
+ * Querry the currently selected angle.
  * @param nav Specifies the connection to the DVD navigator.
  *
  * @return If successful DVD_E_Ok is returned. Otherwise an error code
@@ -455,6 +490,142 @@ DVDResult_t DVDGetCurrentAngle(DVDNav_t *nav, int *const AnglesAvailable,
 }
 
 
+/** 
+ * Querry the number of Titel tracks on the DVD.
+ * @param nav Specifies the connection to the DVD navigator.
+ * @param TitlesAvailable Will contain the number of Title tracks.
+ *
+ * @return If successful DVD_E_Ok is returned. Otherwise an error code
+ * is returned.
+ *
+ * @retval DVD_E_Ok Success.
+ * @retval DVD_E_NotImplemented The function is not implemented.
+ */
+DVDResult_t DVDGetTitles(DVDNav_t *nav, int *const TitlesAvailable)
+{
+  MsgEvent_t ev;
+  ev.type = MsgEventQDVDCtrl;
+  ev.dvdctrl.cmd.type = DVDCtrlGetTitles;
+
+  if(MsgSendEvent(nav->msgq, nav->client, &ev, 0) == -1) {
+    return DVD_E_Unspecified;
+  }
+
+  while(1) {
+    if(MsgNextEvent(nav->msgq, &ev) == -1) {
+      return DVD_E_Unspecified;
+    }
+    if((ev.type == MsgEventQDVDCtrl) &&
+       (ev.dvdctrl.cmd.type == DVDCtrlTitles)) {
+      *TitlesAvailable = ev.dvdctrl.cmd.titles.titles;
+      return DVD_E_Ok;
+    }
+  }
+}
+
+/** 
+ * Querry the current domain.
+ * @param nav Specifies the connection to the DVD navigator.
+ * @param Domain Will contain the current domain.
+ *
+ * @return If successful DVD_E_Ok is returned. Otherwise an error code
+ * is returned.
+ *
+ * @retval DVD_E_Ok Success.
+ * @retval DVD_E_NotImplemented The function is not implemented.
+ */
+DVDResult_t DVDGetCurrentDomain(DVDNav_t *nav, DVDDomain_t *const Domain)
+{
+  MsgEvent_t ev;
+  ev.type = MsgEventQDVDCtrl;
+  ev.dvdctrl.cmd.type = DVDCtrlGetCurrentDomain;
+
+  if(MsgSendEvent(nav->msgq, nav->client, &ev, 0) == -1) {
+    return DVD_E_Unspecified;
+  }
+
+  while(1) {
+    if(MsgNextEvent(nav->msgq, &ev) == -1) {
+      return DVD_E_Unspecified;
+    }
+    if((ev.type == MsgEventQDVDCtrl) &&
+       (ev.dvdctrl.cmd.type == DVDCtrlCurrentDomain)) {
+      *Domain = ev.dvdctrl.cmd.domain.domain;
+      return DVD_E_Ok;
+    }
+  }  
+}
+
+/** 
+ * Get the current location information.
+ * @param nav Specifies the connection to the DVD navigator.
+ * @param Location Will contain the current location information.
+ *
+ * @return If successful DVD_E_Ok is returned. Otherwise an error code
+ * is returned.
+ *
+ * @retval DVD_E_Ok Success.
+ * @retval DVD_E_NotImplemented The function is not implemented.
+ */
+DVDResult_t DVDGetCurrentLocation(DVDNav_t *nav, DVDLocation_t *const Location)
+{
+  MsgEvent_t ev;
+  ev.type = MsgEventQDVDCtrl;
+  ev.dvdctrl.cmd.type = DVDCtrlGetCurrentLocation;
+
+  if(MsgSendEvent(nav->msgq, nav->client, &ev, 0) == -1) {
+    return DVD_E_Unspecified;
+  }
+
+  while(1) {
+    if(MsgNextEvent(nav->msgq, &ev) == -1) {
+      return DVD_E_Unspecified;
+    }
+    if((ev.type == MsgEventQDVDCtrl) &&
+       (ev.dvdctrl.cmd.type == DVDCtrlCurrentLocation)) {
+      *Location = ev.dvdctrl.cmd.location.location;
+      return DVD_E_Ok;
+    }
+  }  
+}
+
+
+/** 
+ * Querry the number of Part's (Chapters) for a Title track.
+ * @param nav Specifies the connection to the DVD navigator.
+ * @param Title The Title track number.
+ * @param PartsAvailable Will contain the number of Title tracks.
+ *
+ * @return If successful DVD_E_Ok is returned. Otherwise an error code
+ * is returned.
+ *
+ * @retval DVD_E_Ok Success.
+ * @retval DVD_E_NotImplemented The function is not implemented.
+ */
+DVDResult_t DVDGetNumberOfPTTs(DVDNav_t *nav, DVDTitle_t Title, 
+			       int *const PartsAvailable)
+{
+  MsgEvent_t ev;
+  ev.type = MsgEventQDVDCtrl;
+  ev.dvdctrl.cmd.type = DVDCtrlGetNumberOfPTTs;
+  ev.dvdctrl.cmd.parts.title = Title;
+
+  if(MsgSendEvent(nav->msgq, nav->client, &ev, 0) == -1) {
+    return DVD_E_Unspecified;
+  }
+
+  while(1) {
+   if(MsgNextEvent(nav->msgq, &ev) == -1) {
+     return DVD_E_Unspecified;
+   }
+   if((ev.type == MsgEventQDVDCtrl) &&
+      (ev.dvdctrl.cmd.type == DVDCtrlNumberOfPTTs)) {
+     *PartsAvailable = ev.dvdctrl.cmd.parts.ptts;
+     return DVD_E_Ok;
+    }
+  }
+}
+
 /** 
  * @todo Implement function.
  *
@@ -467,7 +638,7 @@ DVDResult_t DVDGetCurrentAngle(DVDNav_t *nav, int *const AnglesAvailable,
  * @retval DVD_E_NotImplemented The function is not implemented.
  */
 DVDResult_t DVDGetCurrentVideoAttributes(DVDNav_t *nav,
-					 const DVDVideoAttributes_t *Attr)
+					 DVDVideoAttributes_t *const Attr)
 {
   return DVD_E_NotImplemented;
 }
@@ -583,7 +754,7 @@ DVDResult_t DVDIsSubpictureStreamEnabled(DVDNav_t *nav,
  */
 DVDResult_t DVDGetSubpictureAttributes(DVDNav_t *nav,
 				       DVDSubpictureStream_t StreamNr,
-				       const DVDSubpictureAttributes_t *Attr)
+				       DVDSubpictureAttributes_t *const Attr)
 {
   MsgEvent_t ev;
   ev.type = MsgEventQDVDCtrl;
@@ -629,7 +800,7 @@ DVDResult_t DVDGetSubpictureAttributes(DVDNav_t *nav,
  */
 DVDResult_t DVDGetSubpictureLanguage(DVDNav_t *nav,
 				     DVDSubpictureStream_t StreamNr,
-				     const DVDLangID_t *Language)
+				     DVDLangID_t *const Language)
 {
   return DVD_E_NotImplemented;
 }
@@ -647,8 +818,8 @@ DVDResult_t DVDGetSubpictureLanguage(DVDNav_t *nav,
  * @retval DVD_E_NotImplemented The function is not implemented.
  */
 DVDResult_t DVDGetDefaultSubpictureLanguage(DVDNav_t *nav,
-					    const DVDLangID_t *Language,
-					    const DVDSubpictureLangExt_t *SubpictureExtension)
+					    DVDLangID_t *const Language,
+					    DVDSubpictureLangExt_t *const SubpictureExtension)
 {
   return DVD_E_NotImplemented;
 }
