@@ -51,7 +51,7 @@ typedef enum {
   DVDCtrlTopPGSearch,
 
   DVDCtrlPTTSearch,
-  DVDCtrlPTTPlay,
+  DVDCtrlPTTPlay, /* 10 */
   
   
 
@@ -69,7 +69,7 @@ typedef enum {
   DVDCtrlDefaultAudioLanguageSelect,
   DVDCtrlDefaultSubpictureLanguageSelect,
 
-  DVDCtrlParentalCountrySelect,
+  DVDCtrlParentalCountrySelect, /* 20 */
   DVDCtrlParentalLevelSelect,
 
   DVDCtrlAudioStreamChange,
@@ -79,6 +79,7 @@ typedef enum {
 
 
   /* infocmds */
+
   DVDCtrlGetCurrentAudio,
   DVDCtrlCurrentAudio,
 
@@ -87,8 +88,7 @@ typedef enum {
   
   DVDCtrlGetAudioAttributes,
   DVDCtrlAudioAttributes,
-
-
+ 
   DVDCtrlGetCurrentSubpicture,
   DVDCtrlCurrentSubpicture,
 
@@ -101,11 +101,25 @@ typedef enum {
   DVDCtrlGetCurrentAngle,
   DVDCtrlCurrentAngle,
 
-  DVDCtrlPlayerRegionSelect
+  DVDCtrlPlayerRegionSelect,
+  
+  DVDCtrlGetCurrentUOPS,
+  DVDCtrlCurrentUOPS,
+  
+  DVDCtrlGetTitles,
+  DVDCtrlTitles,
+  
+  DVDCtrlGetNumberOfPTTs,
+  DVDCtrlNumberOfPTTs,
+  
+  DVDCtrlGetCurrentDomain,
+  DVDCtrlCurrentDomain,
+  
+  DVDCtrlGetCurrentLocation,
+  DVDCtrlCurrentLocation
 
 } DVDCtrlEventType_t;
 
-
 typedef enum {
   DVDCtrlLongSetDVDRoot
 } DVDCtrlLongEventType_t;
@@ -255,7 +269,10 @@ typedef struct {
 } DVDCtrlStopEvent_t;
 */
 
-
+typedef struct {
+  DVDCtrlEventType_t type;
+  DVDUOP_t uops;
+} DVDCtrlCurrentUOPS_t;
 
 typedef struct {
   DVDCtrlEventType_t type;
@@ -304,6 +321,26 @@ typedef struct {
   DVDAudioAttributes_t attr;
 } DVDCtrlAudioAttributesEvent_t;
 
+typedef struct {
+  DVDCtrlEventType_t type;
+  DVDDomain_t domain;
+} DVDCtrlCurrentDomainEvent_t;
+
+typedef struct {
+  DVDCtrlEventType_t type;
+  DVDLocation_t location;
+} DVDCtrlCurrentLocationEvent_t;
+
+typedef struct {
+  DVDCtrlEventType_t type;
+  int titles;
+} DVDCtrlTitlesEvent_t;
+
+typedef struct {
+  DVDCtrlEventType_t type;
+  DVDTitle_t title;
+  int ptts;
+} DVDCtrlNumberOfPTTsEvent_t;
 
 typedef struct {
   DVDCtrlEventType_t type;
@@ -420,16 +457,24 @@ typedef union {
   DVDCtrlSubpictureStateEvent_t subpicturestate;
 
   DVDCtrlAngleChangeEvent_t anglechange;
+  
   /* infocmd */
+  DVDCtrlCurrentUOPS_t currentuops;
 
   DVDCtrlCurrentAudioEvent_t currentaudio;
   DVDCtrlAudioStreamEnabledEvent_t audiostreamenabled;
   DVDCtrlAudioAttributesEvent_t audioattributes;
 
+  DVDCtrlTitlesEvent_t titles;
+  DVDCtrlNumberOfPTTsEvent_t parts;
+
   DVDCtrlCurrentSubpictureEvent_t currentsubpicture;
   DVDCtrlSubpictureStreamEnabledEvent_t subpicturestreamenabled;
   DVDCtrlSubpictureAttributesEvent_t subpictureattributes;
   DVDCtrlCurrentAngleEvent_t currentangle;
+  
+  DVDCtrlCurrentDomainEvent_t domain;
+  DVDCtrlCurrentLocationEvent_t location;
   /* end infocmd */
 
 } DVDCtrlEvent_t;
